@@ -338,14 +338,18 @@ void MainWindow::replaceRepos(const QString &url)
     QString ver_name;
     if (ver_num == "9") {
         ver_name = "stretch";
-    } else if (ver_num == "10") {
-        ver_name = "testing";
+     } else if (ver_num == "10") {
+        ver_name = "buster";
+    } else if (ver_num == "11") {
+        ver_name = "bullseye";
     }
 
     // for antiX repos
     QString antix_file = "/etc/apt/sources.list.d/antix.list";
     if (url == "http://mxrepo.com") {
         repo_line_antix = "http://la.mxrepo.com/antix/" + ver_name + "/";
+    } else if (ver_name == "") {
+        repo_line_antix = url + "/antix/";
     } else {
         repo_line_antix = url + "/antix/" + ver_name + "/";
     }
